@@ -1,3 +1,4 @@
+import os.path
 import tensorflow as tf
 
 def get_pretrained_network(file_id=None,
@@ -28,7 +29,7 @@ def get_pretrained_network(file_id=None,
 
     Example
     -------
-    >>> model_file = get_pretrained_network('dbpn4x')
+    >>> model_file = get_pretrained_network('brainExtraction')
     """
 
     def switch_networks(argument):
@@ -39,11 +40,16 @@ def get_pretrained_network(file_id=None,
             "brainExtraction": "https://ndownloader.figshare.com/files/22944632",
             "brainExtractionT1": "https://ndownloader.figshare.com/files/27334370",
             "brainExtractionT1v1": "https://ndownloader.figshare.com/files/28057626",
-            "brainExtractionRobustT1": "https://figshare.com/ndownloader/files/34792930",
+            "brainExtractionRobustT1": "https://figshare.com/ndownloader/files/34821874",
             "brainExtractionT2": "https://ndownloader.figshare.com/files/23066153",
+            "brainExtractionRobustT2": "https://figshare.com/ndownloader/files/34870416",
+            "brainExtractionRobustT2Star": "https://figshare.com/ndownloader/files/34870413",
             "brainExtractionFLAIR": "https://ndownloader.figshare.com/files/23562194",
+            "brainExtractionRobustFLAIR": "https://figshare.com/ndownloader/files/34870407",
             "brainExtractionBOLD": "https://ndownloader.figshare.com/files/22761977",
+            "brainExtractionRobustBOLD": "https://figshare.com/ndownloader/files/34870404",
             "brainExtractionFA": "https://ndownloader.figshare.com/files/22761926",
+            "brainExtractionRobustFA": "https://figshare.com/ndownloader/files/34870410",
             "brainExtractionNoBrainer": "https://ndownloader.figshare.com/files/22598039",
             "brainExtractionInfantT1T2": "https://ndownloader.figshare.com/files/22968833",
             "brainExtractionInfantT1": "https://ndownloader.figshare.com/files/22968836",
@@ -57,7 +63,6 @@ def get_pretrained_network(file_id=None,
             "claustrum_coronal_1": "https://ndownloader.figshare.com/files/27844071",
             "claustrum_coronal_2": "https://ndownloader.figshare.com/files/27844065",
             "ctHumanLung": "https://ndownloader.figshare.com/files/20005217",
-            "dbpn4x": "https://ndownloader.figshare.com/files/13347617",
             "deepFlashLeftT1": "https://ndownloader.figshare.com/files/28966269",
             "deepFlashRightT1": "https://ndownloader.figshare.com/files/28966266",
             "deepFlashLeftBoth": "https://ndownloader.figshare.com/files/28966275",
@@ -82,6 +87,9 @@ def get_pretrained_network(file_id=None,
             "dktOuter": "https://ndownloader.figshare.com/files/23765132",
             "dktOuterWithSpatialPriors": "https://ndownloader.figshare.com/files/24230768",
             "elBicho": "https://ndownloader.figshare.com/files/26736779",
+            "e13x5_coronal_weights": "https://figshare.com/ndownloader/files/35211226",
+            "e13x5_sagittal_weights": "https://figshare.com/ndownloader/files/35211220",
+            "allen_brain_mask_weights" : "https://figshare.com/ndownloader/files/36999880",
             "ewDavidSysu": "https://ndownloader.figshare.com/files/28757622", # "https://ndownloader.figshare.com/files/28403973",
             "ewDavidSysuRankedIntensity": "https://ndownloader.figshare.com/files/28403937",
             "ewDavidSysuT1Only": "https://ndownloader.figshare.com/files/28757628", #"https://ndownloader.figshare.com/files/28403934",
@@ -107,12 +115,12 @@ def get_pretrained_network(file_id=None,
             "hippMapp3rRefine": "https://ndownloader.figshare.com/files/18068411",
             "hypothalamus": "https://ndownloader.figshare.com/files/28344378",
             "koniqMBCS": "https://ndownloader.figshare.com/files/24967376",
-            "koniqMS": "https://ndownloader.figshare.com/files/25461887",
-            "koniqMS2": "https://ndownloader.figshare.com/files/25474850",
+            "koniqMS": "https://figshare.com/ndownloader/files/35295403",
+            "koniqMS2": "https://figshare.com/ndownloader/files/35295397",
             "koniqMS3": "https://ndownloader.figshare.com/files/25474847",
             "lungCtWithPriorsSegmentationWeights": "https://ndownloader.figshare.com/files/28357818",
             "maskLobes": "https://figshare.com/ndownloader/files/30678458",
-            "mriSuperResolution": "https://ndownloader.figshare.com/files/24128618",
+            "mriSuperResolution": "https://figshare.com/ndownloader/files/35290684",
             "protonLungMri": "https://ndownloader.figshare.com/files/13606799",
             "protonLobes": "https://figshare.com/ndownloader/files/30678455",
             "sixTissueOctantBrainSegmentation": "https://ndownloader.figshare.com/files/23776025",
@@ -123,7 +131,7 @@ def get_pretrained_network(file_id=None,
             "sysuMediaWmhFlairT1Model0": "https://ndownloader.figshare.com/files/22898450",
             "sysuMediaWmhFlairT1Model1": "https://ndownloader.figshare.com/files/22898453",
             "sysuMediaWmhFlairT1Model2": "https://ndownloader.figshare.com/files/22898459",
-            "tidsQualityAssessment": "https://ndownloader.figshare.com/files/24292895",
+            "tidsQualityAssessment": "https://figshare.com/ndownloader/files/35295391",
             "wholeTumorSegmentationT2Flair": "https://ndownloader.figshare.com/files/14087045",
             "wholeLungMaskFromVentilation": "https://ndownloader.figshare.com/files/28914441"
         }
@@ -132,8 +140,7 @@ def get_pretrained_network(file_id=None,
     if file_id == None:
         raise ValueError("Missing file id.")
 
-    valid_list = ("dbpn4x",
-                  "arterialLesionWeibinShi",
+    valid_list = ("arterialLesionWeibinShi",
                   "brainAgeGender",
                   "brainAgeDeepBrainNet",
                   "brainExtraction",
@@ -141,9 +148,14 @@ def get_pretrained_network(file_id=None,
                   "brainExtractionT1v1",
                   "brainExtractionRobustT1",
                   "brainExtractionT2",
+                  "brainExtractionRobustT2",
+                  "brainExtractionRobustT2Star",
                   "brainExtractionFLAIR",
+                  "brainExtractionRobustFLAIR",
                   "brainExtractionBOLD",
+                  "brainExtractionRobustBOLD",
                   "brainExtractionFA",
+                  "brainExtractionRobustFA",
                   "brainExtractionNoBrainer",
                   "brainExtractionInfantT1T2",
                   "brainExtractionInfantT1",
@@ -180,6 +192,9 @@ def get_pretrained_network(file_id=None,
                   "dktInner",
                   "dktOuter",
                   "dktOuterWithSpatialPriors",
+                  "e13x5_coronal_weights",
+                  "e13x5_sagittal_weights",
+                  "allen_brain_mask_weights",
                   "elBicho",
                   "ewDavidSysu",
                   "ewDavidSysuRankedIntensity",
@@ -242,7 +257,15 @@ def get_pretrained_network(file_id=None,
     if antsxnet_cache_directory == None:
         antsxnet_cache_directory = "ANTsXNet"
 
-    target_file_name_path = tf.keras.utils.get_file(target_file_name, url,
-        cache_subdir = antsxnet_cache_directory)
+    # keras get_file does not work on read-only file systems. It will attempt to download the file even
+    # if it exists. This is a problem for shared cache directories and read-only containers.
+    #
+    # Check if the file exists here, and if so, return it. Else let keras handle the download
+    target_file_name_path = os.path.join(os.path.expanduser('~'), '.keras', antsxnet_cache_directory,
+                                        target_file_name)
+
+    if not os.path.exists(target_file_name_path):
+        target_file_name_path = tf.keras.utils.get_file(target_file_name, url,
+                                                        cache_subdir = antsxnet_cache_directory)
 
     return(target_file_name_path)
